// Copyright 2019 The Kubernetes Authors.
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//     http://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.

package controller

func init() {
	// stop helmrepo channel controller, which is for creating local helm deployables for the helm repo
	// The local helm deployables are not used any more as the helm repo subscription generates its own topology list by helm release dry run
	// AddToManagerFuncs is a list of functions to create controllers and add them to a manager.
	// AddToManagerFuncs = append(AddToManagerFuncs, helmrepo.Add)
}
